;----------------------------------------------------------------------------
; TI82.H Only for Ash version 2.0
;----------------------------------------------------------------------------

;----------------------------------------------------------------------------
; RAM locations
;----------------------------------------------------------------------------

KEY_0		=$8000	; translated scancode of last key, but 0 if gotten
KEY_1		=$8001	; translated scancode of key down now
KEY_2		=$8002	; same as 8001, but $FF if more than one key is down
KEY_STAT	=$8004	; bit 2 set = key down now
LAST_KEY	=$8006	; last key pressed
CONTRAST	=$8008	; contrast (0..1Fh)
CURSOR_POS      =$800C  ; text position for word ops
CURSOR_ROW	=$800C	; text cursor row
CURSOR_COL	=$800D	; text cursor column
BUSY_COUNTER	=$8026	; counter for busy indicator
BUSY_BITMAP	=$8027	; bitmap for busy indicator
OP1             =$8028  ; OP1
OP2             =$8033  ; OP2
OP3             =$803E  ; OP3
OP4             =$8049  ; OP4
OP5             =$8054  ; OP5
OP6             =$805F  ; OP6
TEXT_MEM	=$808F	; text memory
CURSOR_X	=$8215	; x value of cursor
CURSOR_Y	=$8216	; y value of cursor
_IY_TABLE	=$8528	; where IY usually points
TEXT_MEM2	=$8BDF	; secondary text memory
WIN_START       =$8C8F  ; number of first row in window
WIN_END         =$8C90  ; number of last row in window
VAT_START	=$FE6E	; start of VAT

;----------------------------------------------------------------------------
; ROM routines
;----------------------------------------------------------------------------

; Call these the normal way
LD_HL_MHL       =$0033  ; HL=(HL), A=L
CP_HL_DE        =$0095  ; CP HL,DE (modifies flags only)
UNPACK_HL       =$00A1  ; unpacks one digit of HL into %A
STORE_KEY       =$01C7  ; store immediate keystroke from %A
GET_KEY         =$01D4  ; get immediate keystroke into %A
DISP_DELAY      =$07F3  ; delay for display controller
FIND_PIXEL      =$4166  ; Find pixel (rom page most be 4 otherwise crash)
                        ; Located in the smae place for all the rom versions !

; Call these using rom_calls
KEY_HAND        =$393E-$1A  ; get key using key.handler (using 2nd,aplha +contrast)
TX_CHARPUT      =$39EC-$1A  ; xlated display of %A on screen, normal text style
D_LT_STR        =$3758-$1A  ; display length-byte normal text string
M_CHARPUT       =$37E8-$1A  ; display %A on screen, menu style
D_ZM_STR        =$37EE-$1A  ; display zero-terminated string,  menu style
GET_T_CUR       =$37E2-$1A  ; HL = absolute address of text cursor
LAST_LINE       =$378E-$1A  ; Is it the last line ?
NEXT_LINE       =$3794-$1A  ; goto next line (might scroll)
SCROLL_UP       =$37A0-$1A  ; scroll text screen up
TR_CHARPUT      =$3752-$1A  ; raw display of %A on screen, normal text style
CLEARLCD        =$38B4-$1A  ; clear LCD, but not text or graphics memory
D_HL_DECI       =$3896-$1A  ; disp. HL as 5-byte, right just., blank-pad. decimal
CLEARTEXT_W     =$37CA-$1A  ; clear LCD and text memory,but only current window (affected by 1,(IY+13))
CLEARTEXT_F     =$37BE-$1A  ; clear LCD and text memory (affected by 1,(IY+13))
CLEAR_DISP      =$38E4-$1A  ; clear display
D_ZT_STR        =$3914-$1A  ; display zero-terminated normal text string
BUSY_OFF        =$3932-$1A  ; turn off "busy" indicataor
BUSY_ON         =$394A-$1A  ; turn on "busy" indicator
DONE            =$3884-$1A  ; Print DONE at end of current line
UP_TEXT         =$380C-$1A  ; Update text mem from command shadow

;-----------------------------------------------------------------------------
; Misc
;----------------------------------------------------------------------------

#DEFINE TEXT_START RES 1,(IY+0Dh) \ RES 2,(IY+0Dh) \ ROM_CALL(CLEAR_DISP) \ LD HL,0000h \ LD (CURSOR_POS),HL
#DEFINE TEXT_END SET 2,(IY+0Dh) \ SET 1,(IY+0Dh)

#DEFINE CALL_(addr) CALL $8D76 \ .DW addr
#DEFINE JUMP_(addr) CALL $8D86 \ .DW addr
#DEFINE CALL_Z(addr) CALL $8D74 \ .DW addr
#DEFINE JUMP_Z(addr) CALL $8D84 \ .DW addr
#DEFINE CALL_NZ(addr) CALL $8D78 \ .DW addr
#DEFINE JUMP_NZ(addr) CALL $8D88 \ .DW addr
#DEFINE CALL_C(addr) CALL $8D7C \ .DW addr
#DEFINE JUMP_C(addr) CALL $8D8C \ .DW addr
#DEFINE CALL_NC(addr) CALL $8D80 \ .DW addr
#DEFINE JUMP_NC(addr) CALL $8D90 \ .DW addr
#DEFINE ROM_CALL(addr) CALL $8D96 \ .DW addr

PROGRAM_ADDR = $8D94
